Learn R Programming

intensegRid (version 0.1.2)

get_british_ci: Fetch British carbon intensity data for specified time period

Description

Fetch British carbon intensity data for specified time period

Usage

get_british_ci(start = NULL, end = NULL)

Value

a data.frame with 1/2-hourly carbon intensity data for specified time period

Arguments

start

character A start date of the intesity.

end

character An end date of the intesity data. The maximum date range is limited to 14 days.

Examples

Run this code
if (FALSE) {
get_british_ci()
get_british_ci(start = '2019-01-01', end = '2019-01-02')
}

Run the code above in your browser using DataLab