Learn R Programming

intensegRid (version 0.1.2)

get_national_ci: Get Carbon Intensity data for current half hour for a specified GB Region

Description

Get Carbon Intensity data for current half hour for a specified GB Region

Usage

get_national_ci(start = NULL, end = NULL, region = NULL)

Value

a tibble

Arguments

start

character A start date of the intesity

end

character An end date of the intesity data

region

character The name of the GB region, one of 'England', 'Scotland' or 'Wales'

Examples

Run this code
if (FALSE) {
get_national_ci()
get_national_ci(region = 'England')
get_national_ci(region = 'Scotland')
get_national_ci(region = 'Wales')
get_national_ci(start = '2019-01-01', end = '2019-01-02')
}

Run the code above in your browser using DataLab